@@ -5,4 +5,4 @@ from typing import Optional
 class Config(BaseModel, extra=Extra.ignore):
     qweather_apikey: Optional[str] = None
     qweather_apitype: Optional[str] = None
-    DEBUG: bool = False
+    debug: bool = False
